@@ -404,6 +404,7 @@ class ShipmentDrop(Workflow, ModelSQL, ModelView):
         pool = Pool()
         UoM = pool.get('product.uom')
         Move = pool.get('stock.move')
+        Currency = pool.get('currency.currency')
 
         to_save = []
         cost_exp = Decimal(str(10.0 ** -Move.cost_price.digits[1]))
@@ -422,10 +423,15 @@ class ShipmentDrop(Workflow, ModelSQL, ModelView):
             for s_move in shipment.supplier_moves:
                 if s_move.state == 'cancel':
                     continue
-                if s_move.cost_price:
-                    internal_quantity = Decimal(str(s_move.internal_quantity))
-                    product_cost[s_move.product] += (
-                        s_move.unit_price * internal_quantity)
+                internal_quantity = Decimal(str(s_move.internal_quantity))
+                with Transaction().set_context(date=s_move.effective_date):
+                    unit_price = Currency.compute(
+                        s_move.currency, s_move.unit_price,
+                        s_move.company.currency, round=False)
+                unit_price = UoM.compute_price(
+                    s_move.uom, unit_price, s_move.product.default_uom)
+                product_cost[s_move.product] += (
+                    unit_price * internal_quantity)
 
                 quantity = UoM.compute_qty(
                     s_move.uom, s_move.quantity, s_move.product.default_uom,
@@ -511,26 +517,29 @@ class ShipmentDrop(Workflow, ModelSQL, ModelView):
             requests += PurchaseRequest.search([
                     ('purchase_line', 'in', list(sub_lines)),
                     ])
-        pline2request = {r.purchase_line: r for r in requests}
+        pline2requests = defaultdict(list)
+        for request in requests:
+            pline2requests[request.purchase_line].append(request)
         sale_lines = SaleLine.search([
                 ('purchase_request', 'in', [r.id for r in requests]),
                 ])
-        request2sline = {sl.purchase_request: sl for sl in sale_lines}
+        request2slines = defaultdict(list)
+        for sale_line in sale_lines:
+            request2slines[sale_line.purchase_request].append(sale_line)
 
         to_save = []
         for shipment in shipments:
             for move in shipment.supplier_moves:
                 if not move.origin:
                     continue
-                sale_line = request2sline.get(pline2request.get(move.origin))
-                if not sale_line:
-                    continue
-                for move in sale_line.moves:
-                    if (move.state not in ('cancel', 'done')
-                            and not move.shipment
-                            and move.from_location.type == 'drop'):
-                        move.shipment = shipment
-                        to_save.append(move)
+                for request in pline2requests[move.origin]:
+                    for sale_line in request2slines[request]:
+                        for move in sale_line.moves:
+                            if (move.state not in ('cancel', 'done')
+                                    and not move.shipment
+                                    and move.from_location.type == 'drop'):
+                                move.shipment = shipment
+                                to_save.append(move)
         Move.save(to_save)
         cls._synchronize_moves(shipments)
 
